CanvasModel class
- Annotations
-
- @JsonSerializable.new()
Constructors
- CanvasModel({required int width, required int height, required BackgroundModel background, String? backgroundImage})
-
const
-
CanvasModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- background → BackgroundModel
-
final
- backgroundImage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
final
Methods
-
copyWith(
{int? width, int? height, BackgroundModel? background, String? backgroundImage}) → CanvasModel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited