ShapeLayerModel class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ShapeLayerModel({required String id, required String type, required double x, required double y, required String shapeType, double? width, double? height, String? fillColor, String? strokeColor, double? strokeWidth})
const
ShapeLayerModel.fromJson(Map<String, dynamic> json)
factory

Properties

fillColor String?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
id String
finalinherited
isShape bool
no setterinherited
isText bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shapeType String
final
strokeColor String?
final
strokeWidth double?
final
type String
finalinherited
width double?
final
x double
finalinherited
y double
finalinherited

Methods

copyWith({String? id, String? type, double? x, double? y, String? shapeType, double? width, double? height, String? fillColor, String? strokeColor, double? strokeWidth}) ShapeLayerModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited