TextLayerModel class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

TextLayerModel({required String id, required String type, required double x, required double y, required double fontSize, required String color, required String font, required String defaultText, required String label})
const
TextLayerModel.fromJson(Map<String, dynamic> json)
factory

Properties

color String
final
defaultText String
final
font String
final
fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
isShape bool
no setterinherited
isText bool
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
finalinherited
x double
finalinherited
y double
finalinherited

Methods

copyWith({String? id, String? type, double? x, double? y, double? fontSize, String? color, String? font, String? defaultText, String? label}) TextLayerModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited