TemplateProvider class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addShapeLayer({required String id, required String shapeType, required double x, required double y, double? width, double? height, String? fillColor, String? strokeColor, double? strokeWidth})
→ void
-
-
addTextLayer({required String id, required String label, required String defaultText, required double x, required double y, double fontSize = 24, String color = '#333333', String font = 'poppins_regular.ttf'})
→ void
-
-
clearBackgroundImage()
→ void
-
-
clearEditing()
→ void
-
-
createNewTemplate(String name, String ratio, int width, int height)
→ void
-
-
createTemplateFromForm(BuildContext context)
→ Future<void>
-
-
createTraceTemplate(String name, String backgroundImagePath, {int? width, int? height})
→ void
-
-
deleteLayer(String layerId)
→ void
-
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
exportToJson()
→ Map<String, dynamic>
-
-
initialize()
→ void
-
-
moveLayer(String layerId, int newIndex)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
pickBackgroundImage(BuildContext context)
→ Future<void>
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resetTemplateForm()
→ void
-
-
selectLayer(LayerModel? layer)
→ void
-
-
selectTemplate(TemplateModel template)
→ void
-
-
setBackgroundImage(String imagePath)
→ void
-
-
setBackgroundImageUrl(String? url)
→ void
-
-
setImageDimensions(String width, String height)
→ void
-
-
setIsPickingImage(bool isPicking)
→ void
-
-
setIsTraceMode(bool isTraceMode)
→ void
-
-
setSelectedRatio(String ratio)
→ void
-
-
setTemplateName(String name)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateCurrentTemplateWithImage(String imageDataUrl, int width, int height)
→ void
-
-
updateLayer(LayerModel updatedLayer)
→ void
-
-
updateTemplate(TemplateModel template)
→ void
-