ShapeLayerModel class
Constructors
-
ShapeLayerModel({required String id, required String type, required double x, required double y, required String shapeType, double? width, double? height, String? fillColor, String? strokeColor, double? strokeWidth})
-
const
-
ShapeLayerModel.fromJson(Map<String, dynamic> json)
-
factory
Methods
-
copyWith({String? id, String? type, double? x, double? y, String? shapeType, double? width, double? height, String? fillColor, String? strokeColor, double? strokeWidth})
→ ShapeLayerModel
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
override
-
toString()
→ String
-
A string representation of this object.
inherited